# PyGeomesh

[![Publish](https://github.com/AndPuQing/PyGeomesh/actions/workflows/publish.yml/badge.svg)](https://github.com/AndPuQing/PyGeomesh/actions/workflows/publish.yml) [![wakatime](https://wakatime.com/badge/user/18644ffb-799a-4596-bf9f-2404ba651978/project/f02b8e04-904f-4934-8cb0-443861fa31a5.svg?style=flat-square)](https://wakatime.com/badge/user/18644ffb-799a-4596-bf9f-2404ba651978/project/f02b8e04-904f-4934-8cb0-443861fa31a5) [![Codacy Badge](https://app.codacy.com/project/badge/Grade/f847b41b25e94770aef0590e4bfa59c6)](https://www.codacy.com/gh/AndPuQing/PyGeomesh/dashboard?utm_source=github.com&utm_medium=referral&utm_content=AndPuQing/PyGeomesh&utm_campaign=Badge_Grade) ![PyPI](https://img.shields.io/pypi/v/pygeomesh?style=flat-square) [![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg?style=flat-square)](https://github.com/psf/black) [![Commitizen friendly](https://img.shields.io/badge/commitizen-friendly-brightgreen.svg)](http://commitizen.github.io/cz-cli/)

PyGeomesh is a tool for generating discretized points from geometry.

> This project is building now.

This repository was created for PINN discretization solve domains. It can describe, operate, discretize, and enhance sampling of geometric figures. It has the advantage of being able to group geometric entities and initialize constraints individually.
